@@ -81,6 +81,7 @@ class Workbook(xmlwriter.XMLwriter):
         self.in_memory = options.get('in_memory', False)
         self.excel2003_style = options.get('excel2003_style', False)
         self.remove_timezone = options.get('remove_timezone', False)
+        self.use_future_functions = options.get('use_future_functions', False)
         self.default_format_properties = \
             options.get('default_format_properties', {})
 
@@ -779,6 +780,7 @@ class Workbook(xmlwriter.XMLwriter):
             'excel2003_style': self.excel2003_style,
             'remove_timezone': self.remove_timezone,
             'max_url_length': self.max_url_length,
+            'use_future_functions': self.use_future_functions,
         }
 
         worksheet._initialize(init_data)
@@ -1134,6 +1136,7 @@ class Workbook(xmlwriter.XMLwriter):
         drawing_id = 0
         image_ids = {}
         header_image_ids = {}
+        background_ids = {}
 
         for sheet in self.worksheets():
             chart_count = len(sheet.charts)
@@ -1142,10 +1145,12 @@ class Workbook(xmlwriter.XMLwriter):
 
             header_image_count = len(sheet.header_images)
             footer_image_count = len(sheet.footer_images)
+            has_background = sheet.background_image
             has_drawing = False
 
             if not (chart_count or image_count or shape_count
-                    or header_image_count or footer_image_count):
+                    or header_image_count or footer_image_count
+                    or has_background):
                 continue
 
             # Don't increase the drawing_id header/footer images.
@@ -1153,6 +1158,28 @@ class Workbook(xmlwriter.XMLwriter):
                 drawing_id += 1
                 has_drawing = True
 
+            # Prepare the background images.
+            if sheet.background_image:
+                if sheet.background_bytes:
+                    filename = ''
+                    image_data = sheet.background_image
+                else:
+                    filename = sheet.background_image
+                    image_data = None
+
+                (image_type, width, height, name, x_dpi, y_dpi, digest) = \
+                    self._get_image_properties(filename, image_data)
+
+                if digest in background_ids:
+                    ref_id = background_ids[digest]
+                else:
+                    image_ref_id += 1
+                    ref_id = image_ref_id
+                    background_ids[digest] = image_ref_id
+                    self.images.append([filename, image_type, image_data])
+
+                sheet._prepare_background(ref_id, image_type)
+
             # Prepare the worksheet images.
             for index in range(image_count):
                 filename = sheet.images[index][2]
@@ -1265,10 +1292,12 @@ class Workbook(xmlwriter.XMLwriter):
         marker3 = unpack('2s', data[:2])[0]
         marker4 = unpack('<L', data[:4])[0]
         marker5 = (unpack('4s', data[40:44]))[0]
+        marker6 = unpack('4s', data[:4])[0]
 
         png_marker = b'PNG'
         bmp_marker = b'BM'
         emf_marker = b' EMF'
+        gif_marker = b'GIF8'
 
         if marker1 == png_marker:
             self.image_types['png'] = True
@@ -1290,6 +1319,10 @@ class Workbook(xmlwriter.XMLwriter):
             self.image_types['emf'] = True
             (image_type, width, height, x_dpi, y_dpi) = self._process_emf(data)
 
+        elif marker6 == gif_marker:
+            self.image_types['gif'] = True
+            (image_type, width, height, x_dpi, y_dpi) = self._process_gif(data)
+
         else:
             raise UnsupportedImageFormat(
                 "%s: Unknown or unsupported image file format." % filename)
@@ -1408,6 +1441,16 @@ class Workbook(xmlwriter.XMLwriter):
 
         return 'jpeg', width, height, x_dpi, y_dpi
 
+    def _process_gif(self, data):
+        # Extract width and height information from a GIF file.
+        x_dpi = 96
+        y_dpi = 96
+
+        width = unpack('<h', data[6:8])[0]
+        height = unpack('<h', data[8:10])[0]
+
+        return 'gif', width, height, x_dpi, y_dpi
+
     def _process_bmp(self, data):
         # Extract width and height information from a BMP file.
         width = unpack('<L', data[18:22])[0]
